"use strict";

var fs = require('fs');
var path = require('path');
function readTextAnimations() {
  var filePath = path.join(__dirname, 'text_animations.json');
  try {
    var data = fs.readFileSync(filePath, 'utf8');
    var jsonData = JSON.parse(data);
    return jsonData;
  } catch (err) {
    console.error('读取或解析文件时出错:', err);
    throw err;
  }
}

// 获取所有文字入场动画 0 all 1 vip  2 free
function get_all_ruchang_Effects() {
  var mode = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var text_animations = readTextAnimations();
  var ruchang_effects = text_animations['data'].category_resources['2066'].effect_item_list;
  // console.log(ruchang_effects);

  var filtered_effects = ruchang_effects.filter(function (item) {
    var extra = JSON.parse(item.common_attr.extra);
    if (mode === 1) {
      return extra.is_vip;
    } else if (mode === 2) {
      return !extra.is_vip;
    }
    return true; // mode === 0
  });
  var formatted_effects = filtered_effects.map(function (effect) {
    return {
      "anim_adjust_params": null,
      "category_id": "ruchang",
      "category_name": "入场",
      "duration": 500000,
      "id": effect.common_attr.effect_id,
      "material_type": "sticker",
      "name": effect.common_attr.title,
      "panel": "",
      "path": "",
      "platform": "all",
      "request_id": "",
      "resource_id": effect.common_attr.id,
      "start": 0,
      "type": "in",
      "icon_url": effect.common_attr.cover_url.small
    };
  });

  // console.log(formatted_effects);
  return formatted_effects;
}

// 获取所有文字出场动画 0 all 1 vip  2 free
function get_all_chuchang_Effects() {
  var mode = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var text_animations = readTextAnimations();
  var ruchang_effects = text_animations['data'].category_resources['2067'].effect_item_list;
  // console.log(ruchang_effects);

  var filtered_effects = ruchang_effects.filter(function (item) {
    var extra = JSON.parse(item.common_attr.extra);
    if (mode === 1) {
      return extra.is_vip;
    } else if (mode === 2) {
      return !extra.is_vip;
    }
    return true; // mode === 0
  });
  var formatted_effects = filtered_effects.map(function (effect) {
    return {
      "anim_adjust_params": null,
      "category_id": "chuchang",
      "category_name": "出场",
      "duration": 500000,
      "id": effect.common_attr.effect_id,
      "material_type": "sticker",
      "name": effect.common_attr.title,
      "panel": "",
      "path": "",
      "platform": "all",
      "request_id": "",
      "resource_id": effect.common_attr.id,
      "start": 0,
      "type": "out",
      "icon_url": effect.common_attr.cover_url.small
    };
  });

  // console.log(formatted_effects);
  return formatted_effects;
}

// 获取所有文字loop动画 0 all 1 vip  2 free
function get_all_loop_Effects() {
  var mode = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var text_animations = readTextAnimations();
  var loop_effects = text_animations['data'].category_resources['2133'].effect_item_list;
  // console.log(loop_effects);

  var filtered_effects = loop_effects.filter(function (item) {
    var extra = JSON.parse(item.common_attr.extra);
    if (mode === 1) {
      return extra.is_vip;
    } else if (mode === 2) {
      return !extra.is_vip;
    }
    return true; // mode === 0
  });
  var formatted_effects = filtered_effects.map(function (effect) {
    return {
      "anim_adjust_params": null,
      "category_id": "xunhuan",
      "category_name": "循环",
      "duration": 500000,
      "id": effect.common_attr.effect_id,
      "material_type": "sticker",
      "name": effect.common_attr.title,
      "panel": "",
      "path": "",
      "platform": "all",
      "request_id": "",
      "resource_id": effect.common_attr.id,
      "start": 0,
      "type": "loop",
      "icon_url": effect.common_attr.cover_url.small
    };
  });

  // console.log(formatted_effects);
  return formatted_effects;
}

// 增加一个方法使用title查询文字入场动画
function get_ruchang_Effect_by_title(title) {
  var ruchang_effects = get_all_ruchang_Effects();
  var effect = ruchang_effects.find(function (item) {
    return item.name === title;
  });
  return effect;
}

// 增加一个方法使用title查询文字出场动画
function get_chuchang_Effect_by_title(title) {
  var chuchang_effects = get_all_chuchang_Effects();
  var effect = chuchang_effects.find(function (item) {
    return item.name === title;
  });
  return effect;
}

// 增加一个方法使用title查询文字loop动画
function get_loop_Effect_by_title(title) {
  var loop_effects = get_all_loop_Effects();
  var effect = loop_effects.find(function (item) {
    return item.name === title;
  });
  return effect;
}
module.exports = {
  get_all_ruchang_Effects: get_all_ruchang_Effects,
  get_ruchang_Effect_by_title: get_ruchang_Effect_by_title,
  get_all_chuchang_Effects: get_all_chuchang_Effects,
  get_chuchang_Effect_by_title: get_chuchang_Effect_by_title,
  get_all_loop_Effects: get_all_loop_Effects,
  get_loop_Effect_by_title: get_loop_Effect_by_title
};