"use strict";

var fs = require('fs');
var path = require('path');
function readVideoAnimations() {
  var filePath = path.join(__dirname, 'video_animations.json');
  try {
    var data = fs.readFileSync(filePath, 'utf8');
    var jsonData = JSON.parse(data);
    return jsonData;
  } catch (err) {
    console.error('读取或解析文件时出错:', err);
    throw err;
  }
}

// 获取所有视频入场动画 0 all 1 vip  2 free
function get_all_video_ruchang_Effects() {
  var mode = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var video_animations = readVideoAnimations();
  var ruchang_effects = video_animations['data'].category_resources['3340'].effect_item_list;
  var filtered_effects = ruchang_effects.filter(function (item) {
    var extra = JSON.parse(item.common_attr.extra);
    if (mode === 1) {
      return extra.is_vip;
    } else if (mode === 2) {
      return !extra.is_vip;
    }
    return true; // mode === 0
  });
  var formatted_effects = filtered_effects.map(function (effect) {
    return {
      "anim_adjust_params": null,
      "category_id": "ruchang",
      "category_name": "入场",
      "duration": 500000,
      "id": effect.common_attr.effect_id,
      "material_type": "video",
      "name": effect.common_attr.title,
      "panel": "video",
      "path": "",
      "platform": "all",
      "request_id": "",
      "resource_id": effect.common_attr.id,
      "start": 0,
      "type": "in"
    };
  });
  return formatted_effects;
}

// 获取所有视频出场动画 0 all 1 vip  2 free
function get_all_video_chuchang_Effects() {
  var mode = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var video_animations = readVideoAnimations();
  var chuchang_effects = video_animations['data'].category_resources['3341'].effect_item_list;
  var filtered_effects = chuchang_effects.filter(function (item) {
    var extra = JSON.parse(item.common_attr.extra);
    if (mode === 1) {
      return extra.is_vip;
    } else if (mode === 2) {
      return !extra.is_vip;
    }
    return true; // mode === 0
  });
  var formatted_effects = filtered_effects.map(function (effect) {
    return {
      "anim_adjust_params": null,
      "category_id": "chuchang",
      "category_name": "出场",
      "duration": 500000,
      "id": effect.common_attr.effect_id,
      "material_type": "video",
      "name": effect.common_attr.title,
      "panel": "video",
      "path": "",
      "platform": "all",
      "request_id": "",
      "resource_id": effect.common_attr.id,
      "start": 0,
      "type": "out"
    };
  });
  return formatted_effects;
}

// 获取所有视频循环动画 0 all 1 vip  2 free
function get_all_video_loop_Effects() {
  var mode = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var video_animations = readVideoAnimations();
  var loop_effects = video_animations['data'].category_resources['3342'].effect_item_list;
  var filtered_effects = loop_effects.filter(function (item) {
    var extra = JSON.parse(item.common_attr.extra);
    if (mode === 1) {
      return extra.is_vip;
    } else if (mode === 2) {
      return !extra.is_vip;
    }
    return true; // mode === 0
  });
  var formatted_effects = filtered_effects.map(function (effect) {
    return {
      "anim_adjust_params": null,
      "category_id": "group",
      "category_name": "循环",
      "duration": 500000,
      "id": effect.common_attr.effect_id,
      "material_type": "video",
      "name": effect.common_attr.title,
      "panel": "video",
      "path": "",
      "platform": "all",
      "request_id": "",
      "resource_id": effect.common_attr.id,
      "start": 0,
      "type": "group"
    };
  });
  return formatted_effects;
}

// 增加一个方法使用title查询视频入场动画
function get_video_ruchang_Effect_by_title(title) {
  var ruchang_effects = get_all_video_ruchang_Effects();
  var effect = ruchang_effects.find(function (item) {
    return item.name === title;
  });
  return effect;
}

// 增加一个方法使用title查询视频出场动画
function get_video_chuchang_Effect_by_title(title) {
  var chuchang_effects = get_all_video_chuchang_Effects();
  var effect = chuchang_effects.find(function (item) {
    return item.name === title;
  });
  return effect;
}

// 增加一个方法使用title查询视频循环动画
function get_video_loop_Effect_by_title(title) {
  var loop_effects = get_all_video_loop_Effects();
  var effect = loop_effects.find(function (item) {
    return item.name === title;
  });
  return effect;
}
module.exports = {
  get_all_video_ruchang_Effects: get_all_video_ruchang_Effects,
  get_video_ruchang_Effect_by_title: get_video_ruchang_Effect_by_title,
  get_all_video_chuchang_Effects: get_all_video_chuchang_Effects,
  get_video_chuchang_Effect_by_title: get_video_chuchang_Effect_by_title,
  get_all_video_loop_Effects: get_all_video_loop_Effects,
  get_video_loop_Effect_by_title: get_video_loop_Effect_by_title
};